When L3 gateway support was added, it introduced a port type called
"gateway" and a corresponding option called "gateway-chassis".  Since
that time, we also have an L2 gateway port type called "l2gateway" and a
corresponding option called "l2gateway-chassis".  This patch renames the
L3 gateway port type and option to "l3gateway" and "l3gateway-chassis"
to make things a little more clear and consistent.

Signed-off-by: Russell Bryant <russ...@ovn.org>
---
 ovn/controller/binding.c |  2 +-
 ovn/controller/patch.c   |  4 ++--
 ovn/northd/ovn-northd.c  | 12 ++++++------
 ovn/ovn-sb.xml           | 18 +++++++++---------
 4 files changed, 18 insertions(+), 18 deletions(-)

diff --git a/ovn/controller/binding.c b/ovn/controller/binding.c
index e83c1d5..78ebec4 100644
--- a/ovn/controller/binding.c
+++ b/ovn/controller/binding.c
@@ -219,7 +219,7 @@ consider_local_datapath(struct controller_ctx *ctx,
             add_local_datapath(local_datapaths, binding_rec);
         }
     } else if (chassis_rec && binding_rec->chassis == chassis_rec
-               && strcmp(binding_rec->type, "gateway")) {
+               && strcmp(binding_rec->type, "l3gateway")) {
         if (ctx->ovnsb_idl_txn) {
             VLOG_INFO("Releasing lport %s from this chassis.",
                       binding_rec->logical_port);
diff --git a/ovn/controller/patch.c b/ovn/controller/patch.c
index 707d08b..012e6ba 100644
--- a/ovn/controller/patch.c
+++ b/ovn/controller/patch.c
@@ -346,9 +346,9 @@ add_logical_patch_ports(struct controller_ctx *ctx,
     const struct sbrec_port_binding *binding;
     SBREC_PORT_BINDING_FOR_EACH (binding, ctx->ovnsb_idl) {
         bool local_port = false;
-        if (!strcmp(binding->type, "gateway")) {
+        if (!strcmp(binding->type, "l3gateway")) {
             const char *chassis = smap_get(&binding->options,
-                                           "gateway-chassis");
+                                           "l3gateway-chassis");
             if (chassis && !strcmp(local_chassis_id, chassis)) {
                 local_port = true;
             }
diff --git a/ovn/ovn-sb.xml b/ovn/ovn-sb.xml
index 3d26e65..3cdf91b 100644
--- a/ovn/ovn-sb.xml
+++ b/ovn/ovn-sb.xml
@@ -1420,8 +1420,8 @@ tcp.flags = RST;
       database, which identifies logical ports via the conventions described
       in <code>IntegrationGuide.md</code>.  (The exceptions are for
       <code>Port_Binding</code> records with <code>type</code> of
-      <code>gateway</code>, whose locations are identified by
-      <code>ovn-northd</code> via the <code>options:gateway-chassis</code>
+      <code>l3gateway</code>, whose locations are identified by
+      <code>ovn-northd</code> via the <code>options:l3gateway-chassis</code>
       column in this table.  <code>ovn-controller</code> is still responsible
       to populate the <code>chassis</code> column.)
     </p>
@@ -1475,12 +1475,12 @@ tcp.flags = RST;
             connectivity to the corresponding physical network.
           </dd>
 
-          <dt>gateway</dt>
+          <dt>l3gateway</dt>
           <dd>
             The physical location of the L3 gateway.  To successfully identify 
a
             chassis, this column must be a <ref table="Chassis"/> record.  
This is
             populated by <code>ovn-controller</code> based on the value of
-            the <code>options:gateway-chassis</code> column in this table.
+            the <code>options:l3gateway-chassis</code> column in this table.
           </dd>
 
           <dt>l2gateway</dt>
@@ -1539,7 +1539,7 @@ tcp.flags = RST;
             a logical router to a logical switch or to another logical router.
           </dd>
 
-          <dt><code>gateway</code></dt>
+          <dt><code>l3gateway</code></dt>
           <dd>
             One of a pair of logical ports that act as if connected by a patch
             cable across multiple chassis.  Useful for connecting a logical
@@ -1596,19 +1596,19 @@ tcp.flags = RST;
     <group title="L3 Gateway Options">
       <p>
         These options apply to logical ports with <ref column="type"/> of
-        <code>gateway</code>.
+        <code>l3gateway</code>.
       </p>
 
       <column name="options" key="peer">
         The <ref column="logical_port"/> in the <ref table="Port_Binding"/>
-        record for the other side of the 'gateway' port.  The named <ref
+        record for the other side of the 'l3gateway' port.  The named <ref
         column="logical_port"/> must specify this <ref column="logical_port"/>
-        in its own <code>peer</code> option.  That is, the two 'gateway'
+        in its own <code>peer</code> option.  That is, the two 'l3gateway'
         logical ports must have reversed <ref column="logical_port"/> and
         <code>peer</code> values.
       </column>
 
-      <column name="options" key="gateway-chassis">
+      <column name="options" key="l3gateway-chassis">
         The <code>chassis</code> in which the port resides.
       </column>
     </group>
diff --git a/ovn/northd/ovn-northd.c b/ovn/northd/ovn-northd.c
index 38a3d30..7f5927e 100644
--- a/ovn/northd/ovn-northd.c
+++ b/ovn/northd/ovn-northd.c
@@ -770,10 +770,10 @@ ovn_port_update_sbrec(const struct ovn_port *op)
     sbrec_port_binding_set_datapath(op->sb, op->od->sb);
     if (op->nbrp) {
         /* If the router is for l3 gateway, it resides on a chassis
          * and its port type is "gateway". */
         const char *chassis = smap_get(&op->od->nbr->options, "chassis");
         if (chassis) {
-            sbrec_port_binding_set_type(op->sb, "gateway");
+            sbrec_port_binding_set_type(op->sb, "l3gateway");
         } else {
             sbrec_port_binding_set_type(op->sb, "patch");
         }
@@ -783,7 +783,7 @@ ovn_port_update_sbrec(const struct ovn_port *op)
         smap_init(&new);
         smap_add(&new, "peer", peer);
         if (chassis) {
-            smap_add(&new, "gateway-chassis", chassis);
+            smap_add(&new, "l3gateway-chassis", chassis);
         }
         sbrec_port_binding_set_options(op->sb, &new);
         smap_destroy(&new);
@@ -802,9 +802,9 @@ ovn_port_update_sbrec(const struct ovn_port *op)
             }
 
             /* A switch port connected to a gateway router is also of
-             * type "gateway". */
+             * type "l3gateway". */
             if (chassis) {
-                sbrec_port_binding_set_type(op->sb, "gateway");
+                sbrec_port_binding_set_type(op->sb, "l3gateway");
             } else {
                 sbrec_port_binding_set_type(op->sb, "patch");
             }
@@ -818,7 +818,7 @@ ovn_port_update_sbrec(const struct ovn_port *op)
             smap_init(&new);
             smap_add(&new, "peer", router_port);
             if (chassis) {
-                smap_add(&new, "gateway-chassis", chassis);
+                smap_add(&new, "l3gateway-chassis", chassis);
             }
             sbrec_port_binding_set_options(op->sb, &new);
             smap_destroy(&new);
@@ -770,10 +770,10 @@ ovn_port_update_sbrec(const struct ovn_port *op)
     if (op->nbrp) {
         /* If the router is for l3 gateway, it resides on a chassis
-         * and its port type is "gateway". */
+         * and its port type is "l3gateway". */
         const char *chassis = smap_get(&op->od->nbr->options, "chassis");
         if (chassis) {
-- 
2.7.4

_______________________________________________
dev mailing list
dev@openvswitch.org
http://openvswitch.org/mailman/listinfo/dev

Reply via email to